﻿param($installPath, $toolsPath, $package, $project)

$analyzersDir = Join-Path (Split-Path -Path $toolsPath -Parent) "analyzers"
if (-Not (Test-Path $analyzersDir))
{
    return
}

$analyzersPaths = Join-Path ( $analyzersDir ) * -Resolve

foreach($analyzersPath in $analyzersPaths)
{
    # Uninstall the language agnostic analyzers.
    if (Test-Path $analyzersPath)
    {
        foreach ($analyzerFilePath in Get-ChildItem $analyzersPath -Filter *.dll)
        {
            if($project.Object.AnalyzerReferences)
            {
                $project.Object.AnalyzerReferences.Remove($analyzerFilePath.FullName)
            }
        }
    }
}

# $project.Type gives the language name like (C# or VB.NET)
$languageFolder = ""
if($project.Type -eq "C#")
{
    $languageFolder = "cs"
}
if($project.Type -eq "VB.NET")
{
    $languageFolder = "vb"
}
if($languageFolder -eq "")
{
    return
}

foreach($analyzersPath in $analyzersPaths)
{
    # Uninstall language specific analyzers.
    $languageAnalyzersPath = join-path $analyzersPath $languageFolder
    if (Test-Path $languageAnalyzersPath)
    {
        foreach ($analyzerFilePath in Get-ChildItem $languageAnalyzersPath -Filter *.dll)
        {
            if($project.Object.AnalyzerReferences)
            {
                try
                {
                    $project.Object.AnalyzerReferences.Remove($analyzerFilePath.FullName)
                }
                catch
                {

                }
            }
        }
    }
}
# SIG # Begin signature block
# MIIpQQYJKoZIhvcNAQcCoIIpMjCCKS4CAQExDzANBglghkgBZQMEAgEFADB5Bgor
# BgEEAYI3AgEEoGswaTA0BgorBgEEAYI3AgEeMCYCAwEAAAQQH8w7YFlLCE63JNLG
# KX7zUQIBAAIBAAIBAAIBAAIBADAxMA0GCWCGSAFlAwQCAQUABCB5mT/HBF+ApGFF
# NurlQsK+/gKFs6a98ziX+/GaLDsVJqCCDfQwggZyMIIEWqADAgECAhMzAAAEPxXT
# o2me74nMAAAAAAQ/MA0GCSqGSIb3DQEBDAUAMH4xCzAJBgNVBAYTAlVTMRMwEQYD
# VQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNy
# b3NvZnQgQ29ycG9yYXRpb24xKDAmBgNVBAMTH01pY3Jvc29mdCBDb2RlIFNpZ25p
# bmcgUENBIDIwMTEwHhcNMjQxMTE5MTk1MDU4WhcNMjUxMTEyMTk1MDU4WjBjMQsw
# CQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9u
# ZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMQ0wCwYDVQQDEwQuTkVU
# MIIBojANBgkqhkiG9w0BAQEFAAOCAY8AMIIBigKCAYEAqsr+k9yh9dU/cF9B1Ko8
# T6SaoJNg9kJYh809q0GBZq1WrDbRGcgAClcMmMtAFgIps7Fimyyw/ympDR2Zila5
# iDwHRPpPefdumtlFE2iLDgoZHDXoOs2DdZZza5tYKaA8rmq8vmIh6JfvXHqtlWJd
# s6hAxzHrimvJHUF+Kq5T8n8bRbzOUHbfrvvIYDlQ5YXu1tCFU9mEcVe0y+A3VgsZ
# gEobuJ8UB64Snm0P3eJRNYMELzuNZuwRK+X3VF87u4VRM7t18/csk7ANACbO8/nC
# tT5NzsAdobodUQoSevvY8b474GO9QdMFjXN6PF7oxGq0fT617VN0Nizkl4qAVa9c
# qBhplDelQ20xjzOnFTpHhp9j7/9neYBYkonH9EnLWkIHfCQ7NlDT6vSVyD/tswb9
# jQK7jj5klCrPx9UL3/T7zWCBGbNGp7ylExVt4crtI42CVGC7YpH/IEO2CeCszVVy
# HslZxycPBmRRGBzvLwodkYTl9HnsDMVjnlucqsbWNeqdAgMBAAGjggGCMIIBfjAf
# BgNVHSUEGDAWBgorBgEEAYI3TAgBBggrBgEFBQcDAzAdBgNVHQ4EFgQULPGeoivj
# /NcRbrh1VDqlXOI1df0wVAYDVR0RBE0wS6RJMEcxLTArBgNVBAsTJE1pY3Jvc29m
# dCBJcmVsYW5kIE9wZXJhdGlvbnMgTGltaXRlZDEWMBQGA1UEBRMNNDY0MjIzKzUw
# MzM5MjAfBgNVHSMEGDAWgBRIbmTlUAXTgqoXNzcitW2oynUClTBUBgNVHR8ETTBL
# MEmgR6BFhkNodHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtpb3BzL2NybC9NaWND
# b2RTaWdQQ0EyMDExXzIwMTEtMDctMDguY3JsMGEGCCsGAQUFBwEBBFUwUzBRBggr
# BgEFBQcwAoZFaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraW9wcy9jZXJ0cy9N
# aWNDb2RTaWdQQ0EyMDExXzIwMTEtMDctMDguY3J0MAwGA1UdEwEB/wQCMAAwDQYJ
# KoZIhvcNAQEMBQADggIBAKiH9gTsKkb1QsFOWaiSF1sUpJ/aboTO7pn5eafSaeup
# pt9KVvZaZbZOonaTWyfR9k4M/WPBsyRaIQRDvEhlB1JCcSHUe3TxFdYMyA0ZLLGV
# uUahdJ7KiNo0HrFtQbhtIo/SwcoezS06kShkDx4/PMlSdsp/woebzjuab7sgvSXy
# sX97vj1ZQlESvgldF2wAg5+C0wKCLdB43/H08gq53PcZQ2s5qDvqluZ0tFjNmPEH
# Kh+kaG+xTZCRJQGf/mrTmBlRtKcL293EXNtEO344ybYNoCO7snEI5Ine3vjJgd66
# J7HJqrSYPiKjEZ1KH85n8A6ivR4LlsL87gqrr41NPR6mN3KA3lqWd2jpnS0I7T8W
# Nqk1k9aQQlXHQ8V+TRwvXdDlh5OdIEQ/xrR21yV+lDGjkWsyjeX2UgOg0wFDcX90
# PVPGXP8DPvZb04P38npzWrfKwmyQC3gCA91dfXOg6g9AmUJKZvQbdcEcoZhLw9dt
# 6MM2149eeaz6QIprT6marM21TGXp40N/v/5MXeAk/7LySCHUJWiaIt9lfyOtKdDT
# hSNPFTuXcINaDJOBcY21ranmTsLd/3FKw+Z5UpvxHA83W0qRBq6t5I/C5AKrQZho
# mPyA7QyVsDHs3ekXXZQ11v203ACerQ2KnquSR7gE25yfcz3vF1VV4IA/7HKts8dy
# MIIHejCCBWKgAwIBAgIKYQ6Q0gAAAAAAAzANBgkqhkiG9w0BAQsFADCBiDELMAkG
# A1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQx
# HjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEyMDAGA1UEAxMpTWljcm9z
# b2Z0IFJvb3QgQ2VydGlmaWNhdGUgQXV0aG9yaXR5IDIwMTEwHhcNMTEwNzA4MjA1
# OTA5WhcNMjYwNzA4MjEwOTA5WjB+MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2Fz
# aGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENv
# cnBvcmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBTaWduaW5nIFBDQSAy
# MDExMIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAq/D6chAcLq3YbqqC
# EE00uvK2WCGfQhsqa+laUKq4BjgaBEm6f8MMHt03a8YS2AvwOMKZBrDIOdUBFDFC
# 04kNeWSHfpRgJGyvnkmc6Whe0t+bU7IKLMOv2akrrnoJr9eWWcpgGgXpZnboMlIm
# Ei/nqwhQz7NEt13YxC4Ddato88tt8zpcoRb0RrrgOGSsbmQ1eKagYw8t00CT+OPe
# Bw3VXHmlSSnnDb6gE3e+lD3v++MrWhAfTVYoonpy4BI6t0le2O3tQ5GD2Xuye4Yb
# 2T6xjF3oiU+EGvKhL1nkkDstrjNYxbc+/jLTswM9sbKvkjh+0p2ALPVOVpEhNSXD
# OW5kf1O6nA+tGSOEy/S6A4aN91/w0FK/jJSHvMAhdCVfGCi2zCcoOCWYOUo2z3yx
# kq4cI6epZuxhH2rhKEmdX4jiJV3TIUs+UsS1Vz8kA/DRelsv1SPjcF0PUUZ3s/gA
# 4bysAoJf28AVs70b1FVL5zmhD+kjSbwYuER8ReTBw3J64HLnJN+/RpnF78IcV9uD
# jexNSTCnq47f7Fufr/zdsGbiwZeBe+3W7UvnSSmnEyimp31ngOaKYnhfsi+E11ec
# XL93KCjx7W3DKI8sj0A3T8HhhUSJxAlMxdSlQy90lfdu+HggWCwTXWCVmj5PM4Ta
# sIgX3p5O9JawvEagbJjS4NaIjAsCAwEAAaOCAe0wggHpMBAGCSsGAQQBgjcVAQQD
# AgEAMB0GA1UdDgQWBBRIbmTlUAXTgqoXNzcitW2oynUClTAZBgkrBgEEAYI3FAIE
# DB4KAFMAdQBiAEMAQTALBgNVHQ8EBAMCAYYwDwYDVR0TAQH/BAUwAwEB/zAfBgNV
# HSMEGDAWgBRyLToCMZBDuRQFTuHqp8cx0SOJNDBaBgNVHR8EUzBRME+gTaBLhklo
# dHRwOi8vY3JsLm1pY3Jvc29mdC5jb20vcGtpL2NybC9wcm9kdWN0cy9NaWNSb29D
# ZXJBdXQyMDExXzIwMTFfMDNfMjIuY3JsMF4GCCsGAQUFBwEBBFIwUDBOBggrBgEF
# BQcwAoZCaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraS9jZXJ0cy9NaWNSb29D
# ZXJBdXQyMDExXzIwMTFfMDNfMjIuY3J0MIGfBgNVHSAEgZcwgZQwgZEGCSsGAQQB
# gjcuAzCBgzA/BggrBgEFBQcCARYzaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3Br
# aW9wcy9kb2NzL3ByaW1hcnljcHMuaHRtMEAGCCsGAQUFBwICMDQeMiAdAEwAZQBn
# AGEAbABfAHAAbwBsAGkAYwB5AF8AcwB0AGEAdABlAG0AZQBuAHQALiAdMA0GCSqG
# SIb3DQEBCwUAA4ICAQBn8oalmOBUeRou09h0ZyKbC5YR4WOSmUKWfdJ5DJDBZV8u
# LD74w3LRbYP+vj/oCso7v0epo/Np22O/IjWll11lhJB9i0ZQVdgMknzSGksc8zxC
# i1LQsP1r4z4HLimb5j0bpdS1HXeUOeLpZMlEPXh6I/MTfaaQdION9MsmAkYqwooQ
# u6SpBQyb7Wj6aC6VoCo/KmtYSWMfCWluWpiW5IP0wI/zRive/DvQvTXvbiWu5a8n
# 7dDd8w6vmSiXmE0OPQvyCInWH8MyGOLwxS3OW560STkKxgrCxq2u5bLZ2xWIUUVY
# ODJxJxp/sfQn+N4sOiBpmLJZiWhub6e3dMNABQamASooPoI/E01mC8CzTfXhj38c
# bxV9Rad25UAqZaPDXVJihsMdYzaXht/a8/jyFqGaJ+HNpZfQ7l1jQeNbB5yHPgZ3
# BtEGsXUfFL5hYbXw3MYbBL7fQccOKO7eZS/sl/ahXJbYANahRr1Z85elCUtIEJmA
# H9AAKcWxm6U/RXceNcbSoqKfenoi+kiVH6v7RyOA9Z74v2u3S5fi63V4GuzqN5l5
# GEv/1rMjaHXmr/r8i+sLgOppO6/8MO0ETI7f33VtY5E90Z1WTk+/gFcioXgRMiF6
# 70EKsT/7qMykXcGhiJtXcVZOSEXAQsmbdlsKgEhr/Xmfwb1tbWrJUnMTDXpQzTGC
# GqMwghqfAgEBMIGVMH4xCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9u
# MRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRp
# b24xKDAmBgNVBAMTH01pY3Jvc29mdCBDb2RlIFNpZ25pbmcgUENBIDIwMTECEzMA
# AAQ/FdOjaZ7vicwAAAAABD8wDQYJYIZIAWUDBAIBBQCgga4wGQYJKoZIhvcNAQkD
# MQwGCisGAQQBgjcCAQQwHAYKKwYBBAGCNwIBCzEOMAwGCisGAQQBgjcCARUwLwYJ
# KoZIhvcNAQkEMSIEILtEeMEUesXcycnvAB00C1m+1XkEcUBjfhNIN2IZgfkZMEIG
# CisGAQQBgjcCAQwxNDAyoBSAEgBNAGkAYwByAG8AcwBvAGYAdKEagBhodHRwOi8v
# d3d3Lm1pY3Jvc29mdC5jb20wDQYJKoZIhvcNAQEBBQAEggGAULzdp5VrWNT8rTbj
# hwMJm2a+w40eug68HQCMsdaHPLOCwGkIIwraAt08Y8QETBro/I6GuNe2tYsdBYad
# e4+Dq/GS8w9eAhI2M8dBiqes8NncSxYQzFCJDq/Q+/mFE5JowphFb8UOaflcoDsk
# 9guNZlqPc8T7Tde/d5X0us5ZJ7zY+SeIpqwEwqlkP5HkzT9TFDSNVWmSMLLm8BMz
# ghxeysWsZW3+p7WGcGd/eF39Pk8xY5XRX6SRBqgjdzbTn2eFkRQPRmUrGnAn5uaA
# /ROuwFcDevWGmWT1PSV26kMOZs1E9tJYNYy+vnM6f56vdLuYGwtcG96g+/2hCvYy
# /ioNpmDroBo+3oygfiVf6WPnYgAn141Nu8ZYZOXz+rK9Cy3zIUyUqEUd0GQjFHQv
# uwLeRwqwRt6XabZkPD4F1qnJPAzth2VSnC3Vz6ApTXUti9p94NOgaZD9Et054mij
# zv3nBqxejItxHkQqtQHTQPPcWFjGshZ/kWhl1uE6BUTTvGPfoYIXrTCCF6kGCisG
# AQQBgjcDAwExgheZMIIXlQYJKoZIhvcNAQcCoIIXhjCCF4ICAQMxDzANBglghkgB
# ZQMEAgEFADCCAVoGCyqGSIb3DQEJEAEEoIIBSQSCAUUwggFBAgEBBgorBgEEAYRZ
# CgMBMDEwDQYJYIZIAWUDBAIBBQAEIBo6rZ+ZAgGGk2RXueZ24Cs4Xlwfnw6UaRLH
# 88usDd9OAgZnkNqGXfwYEzIwMjUwMTI0MjEyNjI1LjAwMVowBIACAfSggdmkgdYw
# gdMxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdS
# ZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xLTArBgNVBAsT
# JE1pY3Jvc29mdCBJcmVsYW5kIE9wZXJhdGlvbnMgTGltaXRlZDEnMCUGA1UECxMe
# blNoaWVsZCBUU1MgRVNOOjZGMUEtMDVFMC1EOTQ3MSUwIwYDVQQDExxNaWNyb3Nv
# ZnQgVGltZS1TdGFtcCBTZXJ2aWNloIIR+zCCBygwggUQoAMCAQICEzMAAAH8GKCv
# zGlahzoAAQAAAfwwDQYJKoZIhvcNAQELBQAwfDELMAkGA1UEBhMCVVMxEzARBgNV
# BAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jv
# c29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMdTWljcm9zb2Z0IFRpbWUtU3RhbXAg
# UENBIDIwMTAwHhcNMjQwNzI1MTgzMTE0WhcNMjUxMDIyMTgzMTE0WjCB0zELMAkG
# A1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQx
# HjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEtMCsGA1UECxMkTWljcm9z
# b2Z0IElyZWxhbmQgT3BlcmF0aW9ucyBMaW1pdGVkMScwJQYDVQQLEx5uU2hpZWxk
# IFRTUyBFU046NkYxQS0wNUUwLUQ5NDcxJTAjBgNVBAMTHE1pY3Jvc29mdCBUaW1l
# LVN0YW1wIFNlcnZpY2UwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQCn
# UMAovGltBw9Vg8eUkfJbtbmUFmMlZYOMx+XlbKG4DKU/8sObaFvjKZSZLKZXQQVF
# ByYzwHKnCOFY/wXvHiI7zx370Zn0xCY2HeNIOiGFdeB/ys40QDJ8I9WYnMzvK2y6
# tn3Ghxu4Qvv4/sSQjCg64wWVMXYb/O6rHUT7AA2yWk+o+lvw8LnoFDGAkIjUs4Xm
# WTcB48nvw4vdrD812WS91WXdWAFI9fg1rC3dSBSh+4+f9yn2/AooHC4hZAQVnzfs
# ZdchOyF3Yx+zqhh/FcS2aPZIEYSHFWzvERG5YZvRwrpp/LudoqRtkja/VSqzG5m3
# 3iuf97LbKe+6eXHRHr9vqc2QLWs5MB9aWmwCP9CXPIzq5hNLFhkLZhbMtttGXSVG
# 1LP7hN2lRT+gBlIH5j6zXZGqaDOLtFXE1wjaWb/+wISboDrecIkKBi0z4st72lOy
# GX9Z/w4649BGID6y1OyDz0E4b21uVrPaR946Rh/mF0fymEBu464NB+vqzlhrpb69
# nPoTRmx6fOLQ60x/lEJraEANhWBTEP6CsLwSm19Z5UBaBgJpAWF4039kY1AySTvx
# XrfKg8F98kQC74HnGVM9iiKNR2j01ei8magZePpHxOCyj5A9oAYcrEJsdrVAv0BI
# wXc6zWOuiAIcaLKR+nV0oaeYDnAlPo3HsF52VIOwCQIDAQABo4IBSTCCAUUwHQYD
# VR0OBBYEFJjxpSuxRrOHEHIfv12GJAIv/tB2MB8GA1UdIwQYMBaAFJ+nFV0AXmJd
# g/Tl0mWnG1M1GelyMF8GA1UdHwRYMFYwVKBSoFCGTmh0dHA6Ly93d3cubWljcm9z
# b2Z0LmNvbS9wa2lvcHMvY3JsL01pY3Jvc29mdCUyMFRpbWUtU3RhbXAlMjBQQ0El
# MjAyMDEwKDEpLmNybDBsBggrBgEFBQcBAQRgMF4wXAYIKwYBBQUHMAKGUGh0dHA6
# Ly93d3cubWljcm9zb2Z0LmNvbS9wa2lvcHMvY2VydHMvTWljcm9zb2Z0JTIwVGlt
# ZS1TdGFtcCUyMFBDQSUyMDIwMTAoMSkuY3J0MAwGA1UdEwEB/wQCMAAwFgYDVR0l
# AQH/BAwwCgYIKwYBBQUHAwgwDgYDVR0PAQH/BAQDAgeAMA0GCSqGSIb3DQEBCwUA
# A4ICAQBPuyz9kBnRtNoWyuyIlh3/8tDoiYpv0llIqJHD3GzyHCTlj/vOKCf2Aa3B
# 5EKELaUnwZVEeCsWQHEAKO64+mtLP9RhfufnbYkpy52da4h4TWnfQFmuo9M6exwP
# 3wNmLpY1MDKadpLuK3moCA0iet4AltNTZwCiwmh5cAevnRiBIaWYkz5w3qZgsAvp
# NMUy0Vgmukr1MzlHKHl5mabpRMmcaDSO3WkX/a7w9J3Pd0PLsMXsoMlp3aofFk5G
# 8zeT1Xxifckjlgs+4uyjYnmzd+lfIJWBH+GrzqDnON31tFHLKILyIsib833mrodZ
# WwJ7JJ62up+wPJhZK3Av3qHLsMjIsvmKHxgUx3QB2a9NGjKWYAO4rATZNAJO8+eO
# cuTvKklbb23XtjJrhX4mXPniwGc9TuQh5hmy9RP5gqDKQ/VAH6n65R1Efp7v1VqL
# P6J7Basglni1eQMyYvbWeHSP7nwTV5wBgO9PoHjIUh6ifED/oaX1ezsktyI8IgLq
# EZ2WKIQGnJh5QXSiFkWfs0pC7zQhnSN3nXVYDZurrH1pSr/MXJ/wSDD526dSPUq0
# 2hamrtW4mpqlyRiya+aZgdlcKMrUS6ztXUj5peOsFi6rIz1Cl4VlThTTVgbXm5bB
# QJqPS5mVqH9EZJgx3zjL0MKo6l94oTo8syTuEueG9w5CufE/qTCCB3EwggVZoAMC
# AQICEzMAAAAVxedrngKbSZkAAAAAABUwDQYJKoZIhvcNAQELBQAwgYgxCzAJBgNV
# BAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4w
# HAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xMjAwBgNVBAMTKU1pY3Jvc29m
# dCBSb290IENlcnRpZmljYXRlIEF1dGhvcml0eSAyMDEwMB4XDTIxMDkzMDE4MjIy
# NVoXDTMwMDkzMDE4MzIyNVowfDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hp
# bmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jw
# b3JhdGlvbjEmMCQGA1UEAxMdTWljcm9zb2Z0IFRpbWUtU3RhbXAgUENBIDIwMTAw
# ggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQDk4aZM57RyIQt5osvXJHm9
# DtWC0/3unAcH0qlsTnXIyjVX9gF/bErg4r25PhdgM/9cT8dm95VTcVrifkpa/rg2
# Z4VGIwy1jRPPdzLAEBjoYH1qUoNEt6aORmsHFPPFdvWGUNzBRMhxXFExN6AKOG6N
# 7dcP2CZTfDlhAnrEqv1yaa8dq6z2Nr41JmTamDu6GnszrYBbfowQHJ1S/rboYiXc
# ag/PXfT+jlPP1uyFVk3v3byNpOORj7I5LFGc6XBpDco2LXCOMcg1KL3jtIckw+DJ
# j361VI/c+gVVmG1oO5pGve2krnopN6zL64NF50ZuyjLVwIYwXE8s4mKyzbnijYjk
# lqwBSru+cakXW2dg3viSkR4dPf0gz3N9QZpGdc3EXzTdEonW/aUgfX782Z5F37Zy
# L9t9X4C626p+Nuw2TPYrbqgSUei/BQOj0XOmTTd0lBw0gg/wEPK3Rxjtp+iZfD9M
# 269ewvPV2HM9Q07BMzlMjgK8QmguEOqEUUbi0b1qGFphAXPKZ6Je1yh2AuIzGHLX
# pyDwwvoSCtdjbwzJNmSLW6CmgyFdXzB0kZSU2LlQ+QuJYfM2BjUYhEfb3BvR/bLU
# HMVr9lxSUV0S2yW6r1AFemzFER1y7435UsSFF5PAPBXbGjfHCBUYP3irRbb1Hode
# 2o+eFnJpxq57t7c+auIurQIDAQABo4IB3TCCAdkwEgYJKwYBBAGCNxUBBAUCAwEA
# ATAjBgkrBgEEAYI3FQIEFgQUKqdS/mTEmr6CkTxGNSnPEP8vBO4wHQYDVR0OBBYE
# FJ+nFV0AXmJdg/Tl0mWnG1M1GelyMFwGA1UdIARVMFMwUQYMKwYBBAGCN0yDfQEB
# MEEwPwYIKwYBBQUHAgEWM2h0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2lvcHMv
# RG9jcy9SZXBvc2l0b3J5Lmh0bTATBgNVHSUEDDAKBggrBgEFBQcDCDAZBgkrBgEE
# AYI3FAIEDB4KAFMAdQBiAEMAQTALBgNVHQ8EBAMCAYYwDwYDVR0TAQH/BAUwAwEB
# /zAfBgNVHSMEGDAWgBTV9lbLj+iiXGJo0T2UkFvXzpoYxDBWBgNVHR8ETzBNMEug
# SaBHhkVodHRwOi8vY3JsLm1pY3Jvc29mdC5jb20vcGtpL2NybC9wcm9kdWN0cy9N
# aWNSb29DZXJBdXRfMjAxMC0wNi0yMy5jcmwwWgYIKwYBBQUHAQEETjBMMEoGCCsG
# AQUFBzAChj5odHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtpL2NlcnRzL01pY1Jv
# b0NlckF1dF8yMDEwLTA2LTIzLmNydDANBgkqhkiG9w0BAQsFAAOCAgEAnVV9/Cqt
# 4SwfZwExJFvhnnJL/Klv6lwUtj5OR2R4sQaTlz0xM7U518JxNj/aZGx80HU5bbsP
# MeTCj/ts0aGUGCLu6WZnOlNN3Zi6th542DYunKmCVgADsAW+iehp4LoJ7nvfam++
# Kctu2D9IdQHZGN5tggz1bSNU5HhTdSRXud2f8449xvNo32X2pFaq95W2KFUn0CS9
# QKC/GbYSEhFdPSfgQJY4rPf5KYnDvBewVIVCs/wMnosZiefwC2qBwoEZQhlSdYo2
# wh3DYXMuLGt7bj8sCXgU6ZGyqVvfSaN0DLzskYDSPeZKPmY7T7uG+jIa2Zb0j/aR
# AfbOxnT99kxybxCrdTDFNLB62FD+CljdQDzHVG2dY3RILLFORy3BFARxv2T5JL5z
# bcqOCb2zAVdJVGTZc9d/HltEAY5aGZFrDZ+kKNxnGSgkujhLmm77IVRrakURR6nx
# t67I6IleT53S0Ex2tVdUCbFpAUR+fKFhbHP+CrvsQWY9af3LwUFJfn6Tvsv4O+S3
# Fb+0zj6lMVGEvL8CwYKiexcdFYmNcP7ntdAoGokLjzbaukz5m/8K6TT4JDVnK+AN
# uOaMmdbhIurwJ0I9JZTmdHRbatGePu1+oDEzfbzL6Xu/OHBE0ZDxyKs6ijoIYn/Z
# cGNTTY3ugm2lBRDBcQZqELQdVTNYs6FwZvKhggNWMIICPgIBATCCAQGhgdmkgdYw
# gdMxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdS
# ZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xLTArBgNVBAsT
# JE1pY3Jvc29mdCBJcmVsYW5kIE9wZXJhdGlvbnMgTGltaXRlZDEnMCUGA1UECxMe
# blNoaWVsZCBUU1MgRVNOOjZGMUEtMDVFMC1EOTQ3MSUwIwYDVQQDExxNaWNyb3Nv
# ZnQgVGltZS1TdGFtcCBTZXJ2aWNloiMKAQEwBwYFKw4DAhoDFQBOQSklc5qojbB+
# oGzDg0tXCpiqqqCBgzCBgKR+MHwxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNo
# aW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29y
# cG9yYXRpb24xJjAkBgNVBAMTHU1pY3Jvc29mdCBUaW1lLVN0YW1wIFBDQSAyMDEw
# MA0GCSqGSIb3DQEBCwUAAgUA6z372zAiGA8yMDI1MDEyNDExNDUzMVoYDzIwMjUw
# MTI1MTE0NTMxWjB0MDoGCisGAQQBhFkKBAExLDAqMAoCBQDrPfvbAgEAMAcCAQAC
# Ajy+MAcCAQACAhM7MAoCBQDrP01bAgEAMDYGCisGAQQBhFkKBAIxKDAmMAwGCisG
# AQQBhFkKAwKgCjAIAgEAAgMHoSChCjAIAgEAAgMBhqAwDQYJKoZIhvcNAQELBQAD
# ggEBACO9j9Hv1x4mQDTSob1IjG9YdLoZs9vI5enCeUQwe0cNrufccgFyhxOEU4uQ
# lt99vRj5VaWgSOROhK8vh9TbIqZCBvAXpWyqJRzdl+61guEXMz+bqg0f36drwNug
# sAJT56JyCUoeMl+QZ/gjGdM/NkGfp0GbkyigJuVuZ/dvVrDb2v57cCti21B1xqES
# yh3kMhpNO12gKm0VgvCPuATA3iU2jgajHcfqfO1/rsYS0YJfUqAVToyXot05C0qJ
# Jlv8m0aUtfjElILcOS+OR7pp/clwOHKhuZW7vAiII5XYXTD7dwAI91aqp8EMXB7p
# c7zCv5ey+oRhfno+6x7jY2whUW8xggQNMIIECQIBATCBkzB8MQswCQYDVQQGEwJV
# UzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UE
# ChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSYwJAYDVQQDEx1NaWNyb3NvZnQgVGlt
# ZS1TdGFtcCBQQ0EgMjAxMAITMwAAAfwYoK/MaVqHOgABAAAB/DANBglghkgBZQME
# AgEFAKCCAUowGgYJKoZIhvcNAQkDMQ0GCyqGSIb3DQEJEAEEMC8GCSqGSIb3DQEJ
# BDEiBCABG0AwN82wekFNlq2KObBN/I8IBflIIE0xPGwwKYyu6zCB+gYLKoZIhvcN
# AQkQAi8xgeowgecwgeQwgb0EIJVCr5C77+H8E5U/jDB5TBse4JSGH5PuGrd3kwJo
# 0S1iMIGYMIGApH4wfDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24x
# EDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlv
# bjEmMCQGA1UEAxMdTWljcm9zb2Z0IFRpbWUtU3RhbXAgUENBIDIwMTACEzMAAAH8
# GKCvzGlahzoAAQAAAfwwIgQgIuWi770/4yrOBYWePawa9hOclahFDsbM3XPIp/uR
# CZcwDQYJKoZIhvcNAQELBQAEggIAfSi76Pb1uEQdo5DuCb48gwNTjO1qFoSt9eN/
# 6ZFqnR5pQVxiSTZSMlMhHZGz2cY0dUaTAPfI108Gss1qnhA2tQkE79NSlBsaidEW
# 3oet6iO5+gBkBFmhj6ipDPJKHprqm84lDH23uE3iH0dZSYS/RtJnjW6CibCGYL8o
# +YjQWwwz0T1B/wd2niD6H4dvulxCswY02seZRqHt7OEzGAnLznDtyJsHDPPVM6ur
# tO2cNzkoB4MaZXyVFAO9CO1/Me3vUP+wGI8n8ICoReo+Civs8nOmsXHN+gVS3Ncj
# BtSbKkbemX6d7hh2PEEsp5tMH1RuiltdCBgDw+OfGJQcc0r4H6cutd72feMecbF6
# HVuQj31J1ozttIiOjlNOO3E3cc2XxlZfUPhuLF71RkZmCjegWKEg5/IZgczGKx6I
# WUhCNp8ChTJUWFQ93qUv8hiq/qtt58gB10StNSAsZZDbNc28J5aTt1NT9ocCOnuT
# WrjZeaz5aPOogyXABfL42/5zNo411FnMGrfJNqg9jPhlzPEOrowJmSzf0HvQyrvE
# gFG7QkErb5uIjDWKJzeRACZj8RdkA939uaZ2VvnP8j+3tDWmKaK6+z8zahOFXdP4
# Y1gkZW+x40vlaJKycdV0AvnyWS3uO3u+cXN5pfDvjpNdHUZnatnQRo3KIcOJzzWD
# WC7Hpv4=
# SIG # End signature block
